You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by mr...@apache.org on 2006/07/02 01:37:11 UTC

svn commit: r418521 [8/9] - in /struts/struts2/trunk/core: ./ src/main/java/org/apache/struts/action2/ src/main/java/org/apache/struts2/ src/main/java/org/apache/struts2/components/ src/main/java/org/apache/struts2/components/table/ src/main/java/org/a...

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/config/TestConfiguration.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/config/TestConfiguration.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/config/TestConfiguration.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/config/TestConfiguration.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.config;
+package org.apache.struts2.config;
 
 import java.util.ArrayList;
 import java.util.Iterator;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/AbstractServletDispatcherTestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/AbstractServletDispatcherTestCase.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/AbstractServletDispatcherTestCase.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/AbstractServletDispatcherTestCase.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
@@ -25,9 +25,9 @@
 import com.mockobjects.servlet.MockServletOutputStream;
 import com.opensymphony.xwork.XWorkStatic;
 import com.opensymphony.xwork.config.providers.XmlConfigurationProvider;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletResponse;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletResponse;
 
 import javax.servlet.RequestDispatcher;
 import javax.servlet.ServletContext;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DefautActionMapperTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DefautActionMapperTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DefautActionMapperTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DefautActionMapperTest.java Sat Jul  1 16:36:50 2006
@@ -15,14 +15,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.servlet.MockHttpServletRequest;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.dispatcher.mapper.ActionMapping;
-import org.apache.struts.action2.dispatcher.mapper.DefaultActionMapper;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.dispatcher.mapper.ActionMapping;
+import org.apache.struts2.dispatcher.mapper.DefaultActionMapper;
 
 import java.util.HashMap;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DispatcherUtilsTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DispatcherUtilsTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DispatcherUtilsTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/DispatcherUtilsTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import java.util.Locale;
 
 import org.springframework.mock.web.MockServletContext;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.StrutsTestCase;
 
 import com.opensymphony.xwork.util.LocalizedTextUtil;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/FilterDispatcherTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/FilterDispatcherTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/FilterDispatcherTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/FilterDispatcherTest.java Sat Jul  1 16:36:50 2006
@@ -15,15 +15,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.opensymphony.xwork.ObjectFactory;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.util.ObjectFactoryDestroyable;
-import org.apache.struts.action2.util.ObjectFactoryInitializable;
-import org.apache.struts.action2.util.ObjectFactoryLifecycle;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.util.ObjectFactoryDestroyable;
+import org.apache.struts2.util.ObjectFactoryInitializable;
+import org.apache.struts2.util.ObjectFactoryLifecycle;
 import org.springframework.mock.web.MockFilterConfig;
 import org.springframework.mock.web.MockServletContext;
 
@@ -84,7 +84,7 @@
         DispatcherUtils.setInstance(null);
 
         Map configMap = new HashMap();
-        configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitializableObjectFactory");
+        configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts2.dispatcher.FilterDispatcherTest$InnerInitializableObjectFactory");
         configMap.put(StrutsConstants.STRUTS_CONFIGURATION_XML_RELOAD, "false");
         Configuration.setConfiguration(new InnerConfiguration(configMap));
 
@@ -104,7 +104,7 @@
         DispatcherUtils.setInstance(null);
 
         Map configMap = new HashMap();
-        configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitailizableDestroyableObjectFactory");
+        configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts2.dispatcher.FilterDispatcherTest$InnerInitailizableDestroyableObjectFactory");
         configMap.put(StrutsConstants.STRUTS_CONFIGURATION_XML_RELOAD, "false");
         Configuration.setConfiguration(new InnerConfiguration(configMap));
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/HttpHeaderResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/HttpHeaderResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/HttpHeaderResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/HttpHeaderResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.XWorkTestCase;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/NullActionMapper.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/NullActionMapper.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/NullActionMapper.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/NullActionMapper.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import javax.servlet.http.HttpServletRequest;
 
-import org.apache.struts.action2.dispatcher.mapper.ActionMapper;
-import org.apache.struts.action2.dispatcher.mapper.ActionMapping;
+import org.apache.struts2.dispatcher.mapper.ActionMapper;
+import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
 /**
  * ActionMapper for testing FilterDispatcher (used in FilterDispaatcherTest)

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/PlainTextResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/PlainTextResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/PlainTextResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/PlainTextResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,17 +15,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import java.io.InputStream;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 
 import com.opensymphony.util.ClassLoaderUtil;
-import org.apache.struts.action2.StrutsStatics;
-import org.apache.struts.action2.views.jsp.AbstractUITagTest;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletResponse;
-import org.apache.struts.action2.views.jsp.StrutsMockServletContext;
+import org.apache.struts2.StrutsStatics;
+import org.apache.struts2.views.jsp.AbstractUITagTest;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletResponse;
+import org.apache.struts2.views.jsp.StrutsMockServletContext;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.mock.MockActionInvocation;
 import com.opensymphony.xwork.util.OgnlValueStack;
@@ -55,7 +55,7 @@
 		response.setExpectedHeader("Content-Disposition", "inline");
 		InputStream jspResourceInputStream = 
 			ClassLoaderUtil.getResourceAsStream(
-				"org/apache/struts/action2/dispatcher/someJspFile.jsp",
+				"org/apache/struts2/dispatcher/someJspFile.jsp",
 				PlainTextResultTest.class);
 		
 		
@@ -65,7 +65,7 @@
 			
 			String r = AbstractUITagTest.normalize(stringWriter.getBuffer().toString(), true);
 			String e = AbstractUITagTest.normalize(
-					readAsString("org/apache/struts/action2/dispatcher/someJspFile.jsp"), true);
+					readAsString("org/apache/struts2/dispatcher/someJspFile.jsp"), true);
 			assertEquals(r, e);
 		}
 		finally {
@@ -82,7 +82,7 @@
 		response.setExpectedHeader("Content-Disposition", "inline");
 		InputStream jspResourceInputStream = 
 			ClassLoaderUtil.getResourceAsStream(
-				"org/apache/struts/action2/dispatcher/someJspFile.jsp",
+				"org/apache/struts2/dispatcher/someJspFile.jsp",
 				PlainTextResultTest.class);
 		
 		
@@ -92,7 +92,7 @@
 			
 			String r = AbstractUITagTest.normalize(stringWriter.getBuffer().toString(), true);
 			String e = AbstractUITagTest.normalize(
-					readAsString("org/apache/struts/action2/dispatcher/someJspFile.jsp"), true);
+					readAsString("org/apache/struts2/dispatcher/someJspFile.jsp"), true);
 			assertEquals(r, e);
 		}
 		finally {

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatchedTestAssertInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatchedTestAssertInterceptor.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatchedTestAssertInterceptor.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatchedTestAssertInterceptor.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
-import org.apache.struts.action2.TestAction;
+import org.apache.struts2.TestAction;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.interceptor.Interceptor;
 import junit.framework.Assert;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsStatics;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsStatics;
+import org.apache.struts2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import ognl.Ognl;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletDispatcherTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -25,7 +25,7 @@
  */
 public class ServletDispatcherTest extends AbstractServletDispatcherTestCase {
     public String getConfigFilename() {
-        return "org/apache/struts/action2/dispatcher/ServletDispatcherTest-xwork.xml";
+        return "org/apache/struts2/dispatcher/ServletDispatcherTest-xwork.xml";
     }
 
     public ServletDispatcher getServletDispatcher() {

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletRedirectResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletRedirectResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletRedirectResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/ServletRedirectResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsStatics;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsStatics;
+import org.apache.struts2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.mock.MockActionInvocation;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/SessionMapTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/SessionMapTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/SessionMapTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/SessionMapTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.constraint.Constraint;
 import com.mockobjects.constraint.IsAnything;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StreamResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StreamResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StreamResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StreamResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.opensymphony.util.ClassLoaderUtil;
-import org.apache.struts.action2.ServletActionContext;
+import org.apache.struts2.ServletActionContext;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.mock.MockActionInvocation;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StrutsResultSupportTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StrutsResultSupportTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StrutsResultSupportTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/StrutsResultSupportTest.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.StrutsTestCase;
 /*
  * $Id: StrutsResultSupport.java 394468 2006-04-16 12:16:03Z tmjee $
  *

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/VelocityResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/VelocityResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/VelocityResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/VelocityResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher;
+package org.apache.struts2.dispatcher;
 
 import com.mockobjects.dynamic.Mock;
 import com.opensymphony.xwork.ActionContext;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapperTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapperTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapperTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/DefaultActionMapperTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher.mapper;
+package org.apache.struts2.dispatcher.mapper;
 
 import com.opensymphony.xwork.Result;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.dispatcher.ServletRedirectResult;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.dispatcher.ServletRedirectResult;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletRequest;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapperTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapperTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapperTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/dispatcher/mapper/RestfulActionMapperTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.dispatcher.mapper;
+package org.apache.struts2.dispatcher.mapper;
 
 import junit.framework.TestCase;
 
@@ -23,7 +23,7 @@
 import java.util.Collections;
 import java.util.HashMap;
 
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletRequest;
 
 /**
  * Unit test for {@link RestfulActionMapper}.

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/CreateSessionInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/CreateSessionInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/CreateSessionInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/CreateSessionInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import javax.servlet.http.HttpServletRequest;
 
@@ -23,8 +23,8 @@
 import org.jmock.core.constraint.IsEqual;
 import org.jmock.core.matcher.InvokeOnceMatcher;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
 import com.opensymphony.xwork.mock.MockActionInvocation;
 
 /**

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitDelayAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitDelayAction.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitDelayAction.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitDelayAction.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.opensymphony.xwork.Action;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ExecuteAndWaitInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.config.Configuration;
@@ -27,10 +27,10 @@
 import com.opensymphony.xwork.config.entities.ResultConfig;
 import com.opensymphony.xwork.interceptor.ParametersInterceptor;
 import com.opensymphony.xwork.mock.MockResult;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpSession;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts2.views.jsp.StrutsMockHttpSession;
 
 import javax.servlet.http.HttpSession;
 import java.util.ArrayList;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/FileUploadInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/FileUploadInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/FileUploadInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/FileUploadInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.opensymphony.util.ClassLoaderUtil;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.dispatcher.multipart.MultiPartRequestWrapper;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.dispatcher.multipart.MultiPartRequestWrapper;
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.mock.MockActionInvocation;
 import org.springframework.mock.web.MockHttpServletRequest;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ServletConfigInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ServletConfigInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ServletConfigInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/ServletConfigInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
-import org.apache.struts.action2.StrutsStatics;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.util.ServletContextAware;
+import org.apache.struts2.StrutsStatics;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.util.ServletContextAware;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.mock.MockActionInvocation;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/StrutsConversionErrorInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
@@ -24,7 +24,7 @@
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.ActionSupport;
 import com.opensymphony.xwork.util.OgnlValueStack;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.StrutsTestCase;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,16 +15,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.util.OgnlValueStack;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.TestConfigurationProvider;
-import org.apache.struts.action2.util.TokenHelper;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
-import org.apache.struts.action2.views.jsp.StrutsMockHttpSession;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.TestConfigurationProvider;
+import org.apache.struts2.util.TokenHelper;
+import org.apache.struts2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts2.views.jsp.StrutsMockHttpSession;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptorTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptorTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/interceptor/TokenSessionStoreInterceptorTest.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.interceptor;
+package org.apache.struts2.interceptor;
 
 import com.opensymphony.xwork.ActionProxy;
 import com.opensymphony.xwork.Action;
-import org.apache.struts.action2.TestConfigurationProvider;
+import org.apache.struts2.TestConfigurationProvider;
 
 /**
  * Unit test for {@link TokenSessionStoreInterceptor}.

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletApplicationMapTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletApplicationMapTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletApplicationMapTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletApplicationMapTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet;
+package org.apache.struts2.portlet;
 
 import java.util.ArrayList;
 import java.util.Arrays;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletRequestMapTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletRequestMapTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletRequestMapTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletRequestMapTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet;
+package org.apache.struts2.portlet;
 
 import java.util.ArrayList;
 import java.util.Arrays;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletSessionMapTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletSessionMapTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletSessionMapTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/PortletSessionMapTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet;
+package org.apache.struts2.portlet;
 
 import java.util.Arrays;
 import java.util.Enumeration;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PortletActionContextTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PortletActionContextTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PortletActionContextTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PortletActionContextTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.context;
+package org.apache.struts2.portlet.context;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -31,7 +31,7 @@
 import org.jmock.Mock;
 import org.jmock.MockObjectTestCase;
 
-import org.apache.struts.action2.portlet.PortletActionConstants;
+import org.apache.struts2.portlet.PortletActionConstants;
 import com.opensymphony.xwork.ActionContext;
 
 /**

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PreparatorServletTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PreparatorServletTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PreparatorServletTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/PreparatorServletTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.context;
+package org.apache.struts2.portlet.context;
 
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletContext;
@@ -24,8 +24,8 @@
 
 import org.easymock.MockControl;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
 
 import junit.framework.TestCase;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/ServletContextHolderListenerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/ServletContextHolderListenerTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/ServletContextHolderListenerTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/context/ServletContextHolderListenerTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.context;
+package org.apache.struts2.portlet.context;
 
 import javax.servlet.ServletContext;
 import javax.servlet.ServletContextEvent;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/dispatcher/Jsr168DispatcherTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/dispatcher/Jsr168DispatcherTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/dispatcher/Jsr168DispatcherTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/dispatcher/Jsr168DispatcherTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.dispatcher;
+package org.apache.struts2.portlet.dispatcher;
 
 import java.util.Collections;
 import java.util.HashMap;
@@ -42,8 +42,8 @@
 import org.jmock.cglib.MockObjectTestCase;
 import org.jmock.core.Constraint;
 
-import org.apache.struts.action2.portlet.PortletActionConstants;
-import org.apache.struts.action2.portlet.context.ServletContextHolderListener;
+import org.apache.struts2.portlet.PortletActionConstants;
+import org.apache.struts2.portlet.context.ServletContextHolderListener;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.ActionProxy;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/result/PortletResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/result/PortletResultTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/result/PortletResultTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/result/PortletResultTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.result;
+package org.apache.struts2.portlet.result;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -35,7 +35,7 @@
 import org.jmock.cglib.MockObjectTestCase;
 import org.jmock.core.Constraint;
 
-import org.apache.struts.action2.portlet.PortletActionConstants;
+import org.apache.struts2.portlet.PortletActionConstants;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/PortletUrlHelperTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/PortletUrlHelperTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/PortletUrlHelperTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/PortletUrlHelperTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.util;
+package org.apache.struts2.portlet.util;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -30,7 +30,7 @@
 
 import org.easymock.MockControl;
 
-import org.apache.struts.action2.portlet.context.PortletActionContext;
+import org.apache.struts2.portlet.context.PortletActionContext;
 import com.opensymphony.xwork.ActionContext;
 
 /**

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/StrutsUtilTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/StrutsUtilTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/StrutsUtilTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/portlet/util/StrutsUtilTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.portlet.util;
+package org.apache.struts2.portlet.util;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -28,10 +28,10 @@
 import org.springframework.mock.web.MockHttpServletResponse;
 import org.springframework.mock.web.MockRequestDispatcher;
 
-import org.apache.struts.action2.TestAction;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.util.ListEntry;
-import org.apache.struts.action2.util.StrutsUtil;
+import org.apache.struts2.TestAction;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.util.ListEntry;
+import org.apache.struts2.util.StrutsUtil;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import junit.framework.TestCase;
@@ -48,7 +48,7 @@
 	protected StrutsUtil strutsUtil = null;
 	
 	public void testBeanMethod() throws Exception {
-		Object o = strutsUtil.bean("org.apache.struts.action2.TestAction");
+		Object o = strutsUtil.bean("org.apache.struts2.TestAction");
 		assertNotNull(o);
 		assertTrue(o instanceof TestAction);
 	}

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/sitegraph/SiteGraphTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/sitegraph/SiteGraphTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/sitegraph/SiteGraphTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/sitegraph/SiteGraphTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.sitegraph;
+package org.apache.struts2.sitegraph;
 
 import com.opensymphony.util.ClassLoaderUtil;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.StrutsTestCase;
 
 import java.io.File;
 import java.io.InputStream;
@@ -32,7 +32,7 @@
         // use the classloader rather than relying on the
         // working directory being an assumed value when
         // running the test:  so let's get this class's parent dir 
-        URL url = ClassLoaderUtil.getResource("org/apache/struts/action2/sitegraph/xwork.xml", SiteGraphTest.class);
+        URL url = ClassLoaderUtil.getResource("org/apache/struts2/sitegraph/xwork.xml", SiteGraphTest.class);
         File file = new File(url.toString().substring(5));
         String dir = file.getParent();
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/spring/StrutsSpringObjectFactoryTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/spring/StrutsSpringObjectFactoryTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/spring/StrutsSpringObjectFactoryTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/spring/StrutsSpringObjectFactoryTest.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.spring;
+package org.apache.struts2.spring;
 
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.config.Configuration;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.config.Configuration;
 import junit.framework.TestCase;
 import org.springframework.beans.factory.config.AutowireCapableBeanFactory;
 import org.springframework.mock.web.MockServletContext;
@@ -54,7 +54,7 @@
         ServletContext msc = (ServletContext) new MockServletContext();
         msc.setAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE, ac);
         ac.setServletContext(msc);
-        ac.setConfigLocations(new String[] {"org/apache/struts/action2/spring/StrutsSpringObjectFactoryTest-applicationContext.xml"});
+        ac.setConfigLocations(new String[] {"org/apache/struts2/spring/StrutsSpringObjectFactoryTest-applicationContext.xml"});
         ac.refresh();
 
         fac.init(msc);

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/CounterTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/CounterTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/CounterTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/CounterTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.util;
+package org.apache.struts2.util;
 
 import junit.framework.TestCase;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/InvocationSessionStoreTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/InvocationSessionStoreTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/InvocationSessionStoreTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/InvocationSessionStoreTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.util;
+package org.apache.struts2.util;
 
 import com.mockobjects.dynamic.Mock;
-import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.ActionProxy;
@@ -34,8 +34,8 @@
  */
 public class InvocationSessionStoreTest extends StrutsTestCase {
 
-    private static final String INVOCATION_KEY = "org.apache.struts.action2.util.InvocationSessionStoreTest.invocation";
-    private static final String TOKEN_VALUE = "org.apache.struts.action2.util.InvocationSessionStoreTest.token";
+    private static final String INVOCATION_KEY = "org.apache.struts2.util.InvocationSessionStoreTest.invocation";
+    private static final String TOKEN_VALUE = "org.apache.struts2.util.InvocationSessionStoreTest.token";
 
 
     private ActionInvocation invocation;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/PrefixTrieTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/PrefixTrieTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/PrefixTrieTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/PrefixTrieTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.util;
+package org.apache.struts2.util;
 
 import junit.framework.TestCase;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/StrutsTypeConverterTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/StrutsTypeConverterTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/StrutsTypeConverterTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/StrutsTypeConverterTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.util;
+package org.apache.struts2.util;
 
 import java.util.Date;
 import java.util.HashMap;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/TokenHelperTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/TokenHelperTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/TokenHelperTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/util/TokenHelperTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.util;
+package org.apache.struts2.util;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/TemplateEngineManagerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/TemplateEngineManagerTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/TemplateEngineManagerTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/TemplateEngineManagerTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views;
+package org.apache.struts2.views;
 
-import org.apache.struts.action2.components.template.*;
-import org.apache.struts.action2.config.Configuration;
+import org.apache.struts2.components.template.*;
+import org.apache.struts2.config.Configuration;
 import junit.framework.TestCase;
 
 /**

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerManagerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerManagerTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerManagerTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerManagerTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.freemarker;
+package org.apache.struts2.views.freemarker;
 
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.views.jsp.StrutsMockServletContext;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.views.jsp.StrutsMockServletContext;
 
 /**
  * Test case for FreemarkerManager 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/FreemarkerTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.freemarker;
+package org.apache.struts2.views.freemarker;
 
-import org.apache.struts.action2.util.ListEntry;
-import org.apache.struts.action2.util.StrutsUtil;
+import org.apache.struts2.util.ListEntry;
+import org.apache.struts2.util.StrutsUtil;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import freemarker.ext.beans.CollectionModel;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestAction.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestAction.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestAction.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.freemarker;
+package org.apache.struts2.views.freemarker;
 
 import com.opensymphony.xwork.ActionSupport;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestBean.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestBean.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/freemarker/TestBean.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.freemarker;
+package org.apache.struts2.views.freemarker;
 
 
 /**

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,16 +15,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.TestAction;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.dispatcher.ApplicationMap;
-import org.apache.struts.action2.dispatcher.DispatcherUtils;
-import org.apache.struts.action2.dispatcher.RequestMap;
-import org.apache.struts.action2.dispatcher.SessionMap;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.TestAction;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.dispatcher.ApplicationMap;
+import org.apache.struts2.dispatcher.DispatcherUtils;
+import org.apache.struts2.dispatcher.RequestMap;
+import org.apache.struts2.dispatcher.SessionMap;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ActionTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ActionTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,15 +15,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.util.OgnlValueStack;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.TestAction;
-import org.apache.struts.action2.TestActionTagResult;
-import org.apache.struts.action2.TestConfigurationProvider;
-import org.apache.struts.action2.components.ActionComponent;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.TestAction;
+import org.apache.struts2.TestActionTagResult;
+import org.apache.struts2.TestConfigurationProvider;
+import org.apache.struts2.components.ActionComponent;
 
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.PageContext;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AnchorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AnchorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AnchorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AnchorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.views.jsp.ui.AnchorTag;
-import org.apache.struts.action2.views.jsp.ui.StrutsBodyContent;
+import org.apache.struts2.views.jsp.ui.AnchorTag;
+import org.apache.struts2.views.jsp.ui.StrutsBodyContent;
 
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.JspWriter;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AppendIteratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AppendIteratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AppendIteratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AppendIteratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.struts.action2.views.jsp.iterator.AppendIteratorTag;
+import org.apache.struts2.views.jsp.iterator.AppendIteratorTag;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionSupport;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/BeanTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/BeanTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/BeanTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/BeanTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.JspException;
 
@@ -27,7 +27,7 @@
     public void testSimple() {
         BeanTag tag = new BeanTag();
         tag.setPageContext(pageContext);
-        tag.setName("org.apache.struts.action2.TestAction");
+        tag.setName("org.apache.struts2.TestAction");
 
         try {
             tag.doStartTag();

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseIfTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseIfTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseIfTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseIfTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,14 +15,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.tagext.TagSupport;
 
 import com.mockobjects.servlet.MockJspWriter;
 import com.mockobjects.servlet.MockPageContext;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.components.If;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.components.If;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import junit.framework.TestCase;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ElseTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockJspWriter;
 import com.mockobjects.servlet.MockPageContext;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.components.If;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.components.If;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import junit.framework.TestCase;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IfTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IfTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IfTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IfTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockJspWriter;
 import com.mockobjects.servlet.MockPageContext;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
-import org.apache.struts.action2.ServletActionContext;
+import org.apache.struts2.ServletActionContext;
 import junit.framework.TestCase;
 
 import javax.servlet.jsp.JspException;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IncludeTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IncludeTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IncludeTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IncludeTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockRequestDispatcher;
-import org.apache.struts.action2.components.Include;
+import org.apache.struts2.components.Include;
 import org.easymock.MockControl;
 
 import javax.servlet.RequestDispatcher;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorGeneratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorGeneratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorGeneratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorGeneratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,12 +15,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import java.util.Iterator;
 
-import org.apache.struts.action2.util.IteratorGenerator.Converter;
-import org.apache.struts.action2.views.jsp.iterator.IteratorGeneratorTag;
+import org.apache.struts2.util.IteratorGenerator.Converter;
+import org.apache.struts2.views.jsp.iterator.IteratorGeneratorTag;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionSupport;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/IteratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockBodyContent;
 import com.mockobjects.servlet.MockJspWriter;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/MergeIteratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/MergeIteratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/MergeIteratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/MergeIteratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.struts.action2.views.jsp.iterator.MergeIteratorTag;
+import org.apache.struts2.views.jsp.iterator.MergeIteratorTag;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionSupport;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PortletUrlTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PortletUrlTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PortletUrlTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PortletUrlTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import java.lang.reflect.Field;
 import java.util.Arrays;
@@ -43,13 +43,13 @@
 import org.jmock.core.Constraint;
 
 import com.mockobjects.servlet.MockJspWriter;
-import org.apache.struts.action2.portlet.PortletActionConstants;
-import org.apache.struts.action2.portlet.util.PortletUrlHelper;
-import org.apache.struts.action2.views.jsp.ParamTag;
-import org.apache.struts.action2.dispatcher.DispatcherUtils;
+import org.apache.struts2.portlet.PortletActionConstants;
+import org.apache.struts2.portlet.util.PortletUrlHelper;
+import org.apache.struts2.views.jsp.ParamTag;
+import org.apache.struts2.dispatcher.DispatcherUtils;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
-import org.apache.struts.action2.config.Configuration;
+import org.apache.struts2.config.Configuration;
 
 /**
  */

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PropertyTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PropertyTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PropertyTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PropertyTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,14 +15,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockJspWriter;
 import com.mockobjects.servlet.MockPageContext;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsTestCase;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.config.Configuration;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsTestCase;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.config.Configuration;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PushTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PushTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PushTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/PushTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.JspException;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SetTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SetTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SetTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SetTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.JspException;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SortIteratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SortIteratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SortIteratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SortIteratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.views.jsp.iterator.SortIteratorTag;
+import org.apache.struts2.views.jsp.iterator.SortIteratorTag;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionSupport;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockBodyContent.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockBodyContent.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockBodyContent.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockBodyContent.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.JspWriter;
 import javax.servlet.jsp.tagext.BodyContent;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletRequest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletRequest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletRequest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletRequest.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockHttpServletRequest;
 import junit.framework.AssertionFailedError;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletResponse.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletResponse.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletResponse.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpServletResponse.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockHttpServletResponse;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpSession.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpSession.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpSession.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockHttpSession.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockHttpSession;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockJspWriter.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockJspWriter.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockJspWriter.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockJspWriter.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.jsp.JspWriter;
 import java.io.IOException;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockPageContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockPageContext.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockPageContext.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockPageContext.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import com.mockobjects.servlet.MockPageContext;
 

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockServletContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockServletContext.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockServletContext.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/StrutsMockServletContext.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import javax.servlet.RequestDispatcher;
 import javax.servlet.Servlet;

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SubsetIteratorTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SubsetIteratorTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SubsetIteratorTagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/SubsetIteratorTagTest.java Sat Jul  1 16:36:50 2006
@@ -15,14 +15,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.struts.action2.util.SubsetIteratorFilter.Decider;
-import org.apache.struts.action2.views.jsp.iterator.SubsetIteratorTag;
+import org.apache.struts2.util.SubsetIteratorFilter.Decider;
+import org.apache.struts2.views.jsp.iterator.SubsetIteratorTag;
 import com.opensymphony.xwork.Action;
 import com.opensymphony.xwork.ActionSupport;
--- struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java (original)
+++ struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/AbstractUITagTest.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.views.jsp.ui.AbstractUITag;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.views.jsp.ui.AbstractUITag;
 import com.opensymphony.xwork.ActionContext;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -142,11 +142,11 @@
 
     /**
      * Initialize a map of {@link PropertyHolder} for generic tag property testing. Will be used when calling {@link
      * #verifyGenericProperties(org.apache.struts.action2.views.jsp.ui.AbstractUITag, String, String[])} as properties to
      * verify.<p/> This implementation defines testdata for all common AbstractUITag properties and may be overridden in
      * subclasses.
      *
-     * @return A Map of PropertyHolders values bound to {@link org.apache.struts.action2.views.jsp.AbstractUITagTest.PropertyHolder#getName()}
+     * @return A Map of PropertyHolders values bound to {@link org.apache.struts2.views.jsp.AbstractUITagTest.PropertyHolder#getName()}
      *         as key.
      */
     protected Map initializedGenericTagTestProperties() {
@@ -181,7 +181,7 @@
     /**
      * Do a generic verification that setting certain properties on a tag causes expected output regarding this
      * property. In most cases you would not call this directly, instead use {@link
-     * #verifyGenericProperties(org.apache.struts.action2.views.jsp.ui.AbstractUITag, String, String[])}.
+     * #verifyGenericProperties(org.apache.struts2.views.jsp.ui.AbstractUITag, String, String[])}.
      *
      * @param tag              The fresh created tag instance to test.
      * @param theme            The theme to use. If <tt>null</tt>, use configured default theme.
@@ -142,11 +142,11 @@
     /**
      * Initialize a map of {@link PropertyHolder} for generic tag property testing. Will be used when calling {@link
-     * #verifyGenericProperties(org.apache.struts.action2.views.jsp.ui.AbstractUITag, String, String[])} as properties to
+     * #verifyGenericProperties(org.apache.struts2.views.jsp.ui.AbstractUITag, String, String[])} as properties to
      * verify.<p/> This implementation defines testdata for all common AbstractUITag properties and may be overridden in
      * subclasses.

Modified: struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ActionTagTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/test/java/org/apache/struts2/views/jsp/ActionTagTest.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================